# 2022-09-06 - Composable Stable Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools were deprecated in favor of a new version that supported proportional joins and exits. The factory was superseded by this [updated version (also now deprecated)](../20221122-composable-stable-pool-v2).

Deployment of `ComposableStablePoolFactory`, which allows creating Stable Pools that are suitable to be included in other Pools.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`ComposableStablePoolFactory` artifact](./artifact/ComposableStablePoolFactory.json)
